==> apimodule-1.0.5.tar.gz: lib/msimpersaa/response/pangkat_response.dart <==
class PangkatResponse {
  bool con;
  String msg;
  List<PangkatResults> results;

  PangkatResponse({this.con, this.msg, this.results});

  PangkatResponse.fromJson(Map<String, dynamic> json) {
    con = json['con'];
    msg = json['msg'];
    if (json['results'] != null) {
      results = <PangkatResults>[];
      json['results'].forEach((v) {
        results.add(PangkatResults.fromJson(v));
      });
    }
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = Map<String, dynamic>();
    data['con'] = this.con;
    data['msg'] = this.msg;
    if (this.results != null) {
      data['results'] = this.results.map((v) => v.toJson()).toList();
    }
    return data;
  }
}

class PangkatResults {
  String skNomorPangkat;
  String skTanggalPangkat;
  String pejabatPenetap;
  String pangkatGolongan;
  String tmtPangkat;
  String jenis;
  String documen;
  String pathFile;

  PangkatResults(
      {this.skNomorPangkat,
      this.skTanggalPangkat,
      this.pejabatPenetap,
      this.pangkatGolongan,
      this.tmtPangkat,
      this.jenis,
      this.documen,
      this.pathFile});

  PangkatResults.fromJson(Map<String, dynamic> json) {
    skNomorPangkat = json['sk_nomor_pangkat'];
    skTanggalPangkat = json['sk_tanggal_pangkat'];
    pejabatPenetap = json['pejabat_penetap'];
    pangkatGolongan = json['pangkat_golongan'];
    tmtPangkat = json['tmt_pangkat'];
    jenis = json['jenis'];
    documen = json['dokumen'];
    pathFile = json['path_file'];
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = Map<String, dynamic>();
    data['sk_nomor_pangkat'] = this.skNomorPangkat;
    data['sk_tanggal_pangkat'] = this.skTanggalPangkat;
    data['pejabat_penetap'] = this.pejabatPenetap;
    data['pangkat_golongan'] = this.pangkatGolongan;
    data['tmt_pangkat'] = this.tmtPangkat;
    data['jenis'] = this.jenis;
    data['dokumen'] = this.documen;
    data['path_file'] = this.pathFile;
    return data;
  }
}

==> apimodule-1.0.6.tar.gz: lib/msimpersaa/response/pangkat_response.dart <==
class PangkatResponse {
  bool con;
  String msg;
  List<PangkatResults> results;

  PangkatResponse({this.con, this.msg, this.results});

  PangkatResponse.fromJson(Map<String, dynamic> json) {
    con = json['con'];
    msg = json['msg'];
    if (json['results'] != null) {
      results = <PangkatResults>[];
      json['results'].forEach((v) {
        results.add(PangkatResults.fromJson(v));
      });
    }
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = Map<String, dynamic>();
    data['con'] = this.con;
    data['msg'] = this.msg;
    if (this.results != null) {
      data['results'] = this.results.map((v) => v.toJson()).toList();
    }
    return data;
  }
}

class PangkatResults {
  String skNomorPangkat;
  String skTanggalPangkat;
  String pejabatPenetap;
  String pangkatGolongan;
  String tmtPangkat;
  String jenis;
  String document;
  String pathFile;

  PangkatResults(
      {this.skNomorPangkat,
      this.skTanggalPangkat,
      this.pejabatPenetap,
      this.pangkatGolongan,
      this.tmtPangkat,
      this.jenis,
      this.document,
      this.pathFile});

  PangkatResults.fromJson(Map<String, dynamic> json) {
    skNomorPangkat = json['sk_nomor_pangkat'];
    skTanggalPangkat = json['sk_tanggal_pangkat'];
    pejabatPenetap = json['pejabat_penetap'];
    pangkatGolongan = json['pangkat_golongan'];
    tmtPangkat = json['tmt_pangkat'];
    jenis = json['jenis'];
    document = json['dokumen'];
    pathFile = json['path_file'];
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = Map<String, dynamic>();
    data['sk_nomor_pangkat'] = this.skNomorPangkat;
    data['sk_tanggal_pangkat'] = this.skTanggalPangkat;
    data['pejabat_penetap'] = this.pejabatPenetap;
    data['pangkat_golongan'] = this.pangkatGolongan;
    data['tmt_pangkat'] = this.tmtPangkat;
    data['jenis'] = this.jenis;
    data['dokumen'] = this.document;
    data['path_file'] = this.pathFile;
    return data;
  }
}
